/**
 * XMLファイルとPropertiesオブジェクトの相互変換
 */
package beans;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.faces.context.FacesContext;
import javax.servlet.ServletContext;

public class PropertiesUtil {
    /**
     * XMLからProperties インスタンスを作成して返す
     * @param rpath  xmlファイルのアプリケーションルートからの相対パス
     * @return  Propertiesのインスタンス
     */
    public  static  Properties create(String rpath){
        String path = getRealPath(rpath);
        if(path==null){
            Logger.getLogger(PropertiesUtil.class.getName()).log(Level.SEVERE, "★XMLファイルパスの指定誤り");
        }
        Properties prop = new Properties();
        try {
            prop.loadFromXML(new FileInputStream(path));
        } catch (IOException ex) {
            Logger.getLogger(PropertiesUtil.class.getName()).log(Level.SEVERE, ex.toString());
        }
        return prop;
    }
    /**
     * XML形式で出力する
     * @param prop  出力するPropertiesオブジェクト
     * @param os    出力先ストリーム
     */
    public static void outputXML(Properties prop, OutputStream os){
        try {
            prop.storeToXML(os, null);
        } catch (IOException ex) {
            Logger.getLogger(PropertiesUtil.class.getName()).log(Level.SEVERE, ex.toString());
        }        
    }
    /**
     * アプリケーションルートからの相対パスを絶対パスに変換する
     * @param path  アプリケーションルートのリソースからの相対パス（ex. /resources/～）
     * @return      絶対パス
     */
    public static String getRealPath(String path) {
        ServletContext ctx = (ServletContext) FacesContext.getCurrentInstance().getExternalContext().getContext();
        return ctx.getRealPath(path);
    }
}
